 function [part1,part2] = bisection_inertial(A,xy,picture)
% INERTPART : Inertial partition of a graph.
%
% p = inertpart(A,xy) returns a list of the vertices on one side of a partition
%     obtained by bisection with a line or plane normal to a moment of inertia
%     of the vertices, considered as points in Euclidean space.
%     Input A is the adjacency matrix of the mesh (used only for the picture!);
%     each row of xy is the coordinates of a point in d-space.
%
% inertpart(A,xy,1) also draws a picture.
%
% See also PARTITION


%disp(' ');
%disp(' Numerical Computing @ USI Lugano:   ');
%disp(' Implement inertial bisection');
%disp(' ');


% Steps
% 1. Calculate the center of mass.
m = mean(xy);
xm = m(1);
ym = m(2);

% 2. Construct the matrix M.
%  (Consult the pdf of the assignment for the creation of M) 
sx = (xy(:, 1) - xm);
sy = (xy(:, 2) - ym);
X1 = sum(sx .^ 2);
X2 = dot(sx, sy);
X3 = sum(sy .^ 2);

M = [X1 X2; X2 X3];

% 3. Calculate the smallest eigenvector of M.
[u, ~] = eigs(M,1,'smallestabs');
a = u(1);
b = u(2);

% 4. Find the line L on which the center of mass lies.
v = [-b; a];
v = v / norm(v, 2);

% 5. Partition the points around the line L.
%   (you may use the function partition.m)
[part1, part2] = partition(xy, v);

if picture == 1
    gplotpart(A,xy,part1);
    title('Inertial bisection using the Fiedler Eigenvector');
end

end
