function [part1,part2] = bisection_spectral(A,xy,picture)
% bisection_spectral : Spectral partition of a graph.
%
% [part1,part2] = bisection_spectral(A) returns a partition of the n vertices
%                 of A into two lists part1 and part2 according to the
%                 spectral bisection algorithm of Simon et al:  
%                 Label the vertices with the components of the Fiedler vector
%                 (the second eigenvector of the Laplacian matrix) and partition
%                 them around the median value or 0.



%disp(' ');
%disp(' Numerical Computing @ USI Lugano:   ');
%disp(' Implement inertial bisection');
%disp(' ');

% Steps

% 1. Construct the Laplacian.
D = diag(sum(A, 1));
W = -1 .* A;
L = D + W;

% 2. Calculate its eigensdecomposition.
[V, ~] = eigs(L,2,'smallestabs');
W = V(:,2);

% 3. Label the vertices with the components of the Fiedler vector.
[values, indexes] = sort(W);

% 4. Partition them around their median value, or 0.
cut = size(values(values < 0), 1);
part1 = indexes(1:cut);
part2 = indexes(cut+1:end);

if picture == 1
    gplotpart(A,xy,part1); 
    title('Spectral bisection using the Fiedler Eigenvector');
elseif picture == 2
    drawgraph(A, xy, W, part1, part2)
    % 3d plot
    title('Spectral bisection using the Fiedler Eigenvector');
end
end

function drawgraph(A, xy, W, part1, part2)
    scatter3(xy(:, 1), xy(:, 2), W, 30, W, 'filled')
    colorbar
    
    hold on
    
    gplot(A(part1, part1), xy(part1, :), '-k');
    
    set(gca,'ColorOrder', ones(size(part2, 2), 3) .* 0.3)
    gplot(A(part2, part2), xy(part2, :));
    
    P1P2 = zeros(size(A));
    P1P2(part1, part2) = A(part1, part2);
    P1P2(part2, part1) = A(part2, part1);
    gplot(P1P2, xy, '-r');
    
    hold off
end
